@@ -41,16 +41,31 @@ from sfalmanac.lib.eventtables import maketables as maketables
 from sfalmanac.lib.increments import makelatex as makelatex
 
 
-def makePDF(fn, msg = ""):
-    command = 'pdflatex {}'.format(fn + ".tex")
-    os.system(command)
-    os.remove(fn + ".tex")
-    print("finished" + msg)
+def makePDF(args, fn, msg = ""):
+    command = 'pdflatex {}'.format(args + fn + ".tex")
+    if args == "":
+        os.system(command)
+        print("finished" + msg)
+    else:
+        returned_value = os.system(command)
+        if returned_value != 0:
+            if msg != "":
+                print("ERROR detected while" + msg)
+            else:
+                print("!!   ERROR detected while creating PDF file   !!")
+                print("!! Append '-v' or '-log' for more information !!")
+        else:
+            if msg != "":
+                print("finished" + msg)
+            else:
+                print("finished creating PDF")
     return
 
-def tidy_up(fn):
-    if os.path.isfile(fn + ".log"):
-        os.remove(fn + ".log")
+def tidy_up(kl, fn):
+    os.remove(fn + ".tex")
+    if not kl:
+        if os.path.isfile(fn + ".log"):
+            os.remove(fn + ".log")
     if os.path.isfile(fn + ".aux"):
         os.remove(fn + ".aux")
     return
@@ -115,10 +130,10 @@ def checkCoreCount():       # only called when config.MULTIpr == True
             sys.exit(0)
     if config.CPUcores == 1:
         config.MULTIpr = False
-        print("\nERROR: 2 CPU cores minimum are required for parallel processessing")
+        print("\nERROR: 2 logical processors minimum are required for parallel processessing")
         print("       defaulting to single processessing")
-    if config.CPUcores < 12 or (config.WINpf and config.CPUcores < 8):
-        print("\nNOTE: only {} CPU cores are available for parallel processessing".format(config.CPUcores))
+    if config.CPUcores < 8 or (not config.WINpf and config.CPUcores < 12):
+        print("\nNOTE: only {} logical processors are available for parallel processessing".format(config.CPUcores))
 
 
 ##Main##
@@ -126,6 +141,21 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     if sys.version_info[0] < 3:
         raise Exception("Must be using Python 3")
 
+    try:
+        arg = sys.argv[1]
+    except IndexError:
+        arg = ""
+    if len(sys.argv) > 2 or not (arg == "" or arg == "-v" or arg == "-log"):
+        print("One optional command line parameter is permitted:")
+        print(" python -m skyalmanac -v")
+        print(" ... to send pdfTeX output to the terminal")
+        print(" python -m skyalmanac -log")
+        print(" ... to keep the log file")
+        sys.exit(0)
+
+    args = "" if arg == "-v" else "-interaction=batchmode -halt-on-error "
+    keeplog = True if arg == "-log" else False
+
     d = datetime.datetime.utcnow().date()
     first_day = datetime.date(d.year, d.month, d.day)
 
@@ -140,7 +170,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
         config.pgsz = os.getenv('PGSZ', config.pgsz)
         config.moonimg = os.getenv('MOONIMG', str(config.moonimg))
         config.ephndx = os.getenv('EPHNDX', str(config.ephndx))
-        if config.ephndx not in set(['0', '1', '2']):
+        if config.ephndx not in set(['0', '1', '2', '3', '4']):
             ephERR = True
         else:
             config.ephndx = int(config.ephndx)
@@ -168,7 +198,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
         #first_day = datetime.date(2023, 6, 24)	## for testing a specific date ##
         #d = first_day							## for testing a specific date ##
         spad = "./"
-        if config.ephndx not in set([0, 1, 2]):
+        if config.ephndx not in set([0, 1, 2, 3, 4]):
             ephERR = True
         config.moonimg = str(config.moonimg)
         config.useIERS = str(config.useIERS)
@@ -216,9 +246,12 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     spdf = ""
     spcf = ""
     if sys.platform.startswith('win'):  # Windows 10 (also in 'venv' virtual environment)
-        spad = sys.exec_prefix + "\\Lib\\site-packages\\" + pkg + "\\astro-data\\"  # path to downloaded data
-        spdf = sys.exec_prefix + "\\Lib\\site-packages\\" + pkg + "\\data\\"  # path to data files
-        spcf = sys.exec_prefix + "\\Lib\\site-packages\\" + pkg + "\\lib\\"   # path to config.py
+        syspf = sys.exec_prefix.replace("\\","/")
+        spad = syspf + "/Lib/site-packages/" + pkg + "/astro-data/"  # path to downloaded data
+        spdf = syspf + "/Lib/site-packages/" + pkg + "/data/"  # path to data files
+        spcf = syspf + "/Lib/site-packages/" + pkg + "/lib/"   # path to config.py
+        spcf = spcf.replace("/","\\")
+        spad = spad.replace("/","\\")
     else:                               # POSIX (Linux & Mac OS X)
         if site.ENABLE_USER_SITE:
             spad = site.USER_SITE + "/" + pkg + "/astro-data/"
@@ -309,7 +342,6 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
             for yearint in range(int(yearfr),int(yearto)+1):
                 if config.MULTIpr: checkCoreCount()
                 start = timer_start()
-                config.stopwatch = 0.0      # 00000
                 config.moonDataSeeks = 0
                 config.moonDataFound = 0
                 config.moonHorizonSeeks = 0
@@ -319,15 +351,16 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 print(msg)
     ##            config.writeLOG(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                fn = "almanac{}{}".format(ff,year+DecFmt)
+                ff = "tradna_" if config.tbls != 'm' else "modna_"
+                fn = "{}{}".format(ff,year+DecFmt)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
                 outfile.write(almanac(first_day,122,ts,spad,df180,df360,dfcm))
                 outfile.close()
                 timer_end(start, 1)
                 search_stats()
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(fn, " creating nautical almanac for {}".format(year))
-                tidy_up(fn)
+                makePDF(args, fn, " creating nautical almanac for {}".format(year))
+                tidy_up(keeplog, fn)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
     ##        config.closeLOG()     # close log after the for-loop
 
@@ -337,13 +370,14 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 msg = "\nCreating the sun tables for the year {}\n".format(year)
                 print(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                fn = "sunalmanac{}{}".format(ff,year+DecFmt)
+                ff = "tradst_" if config.tbls != 'm' else "modst_"
+                fn = "{}{}".format(ff,year+DecFmt)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
                 outfile.write(sunalmanac(first_day,25,dfra))
                 outfile.close()
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(fn, " creating sun tables for {}".format(year))
-                tidy_up(fn)
+                makePDF(args, fn, " creating sun tables for {}".format(year))
+                tidy_up(keeplog, fn)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
 
         elif s == '3':      # Event Time tables  (for a year)
@@ -355,15 +389,15 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 msg = "\nCreating the event time tables for the year {}".format(year)
                 print(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                fn = "event-times{}".format(year)
+                fn = "event-times_{}".format(year)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
                 outfile.write(maketables(first_day,183,ts,spad,df180,df360))
                 outfile.close()
                 timer_end(start, 2)
                 print()
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(fn, " creating event time tables for {}".format(year))
-                tidy_up(fn)
+                makePDF(args, fn, " creating event time tables for {}".format(year))
+                tidy_up(keeplog, fn)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
 
         elif s == '4':      # Nautical almanac   -  6 days from today
@@ -372,7 +406,8 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
             start = timer_start()
             msg = "\nCreating nautical almanac tables - from {}\n".format(sdmy)
             print(msg)
-            fn = "almanac{}{}".format(ff,symd+DecFmt)
+            ff = "tradna_" if config.tbls != 'm' else "modna_"
+            fn = "{}{}".format(ff,symd+DecFmt)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
             outfile.write(almanac(first_day,2,ts,spad,df180,df360,dfcm))
             outfile.close()
@@ -381,33 +416,34 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     ##        config.writeLOG('\n\n' + msg1 + '\n' + msg2 + '\n' + msg3)
     ##        config.closeLOG()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-            makePDF(fn)
-            tidy_up(fn)
+            makePDF(args, fn)
+            tidy_up(keeplog, fn)
 
         elif s == '5':      # Sun tables only    - 30 days from today
             msg = "\nCreating the sun tables - from {}\n".format(sdmy)
             print(msg)
-            fn = "sunalmanac{}{}".format(ff,symd+DecFmt)
+            ff = "tradst_" if config.tbls != 'm' else "modst_"
+            fn = "{}{}".format(ff,symd+DecFmt)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
             outfile.write(sunalmanac(first_day,2,dfra))
             outfile.close()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-            makePDF(fn)
-            tidy_up(fn)
+            makePDF(args, fn)
+            tidy_up(keeplog, fn)
 
         elif s == '6':      # Event Time tables  -  6 days from today
             if config.MULTIpr: checkCoreCount()
             start = timer_start()
             msg = "\nCreating event time tables - from {}\n".format(sdmy)
             print(msg)
-            fn = "event-times{}".format(symd)
+            fn = "event-times_{}".format(symd)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
             outfile.write(maketables(first_day,3,ts,spad,df180,df360))
             outfile.close()
             timer_end(start, 2)
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-            makePDF(fn)
-            tidy_up(fn)
+            makePDF(args, fn)
+            tidy_up(keeplog, fn)
 
         elif s == '7':
             msg = "\nCreating the Increments and Corrections tables\n"
@@ -417,8 +453,8 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
             outfile.write(makelatex())
             outfile.close()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-            makePDF(fn)
-            tidy_up(fn)
+            makePDF(args, fn)
+            tidy_up(keeplog, fn)
 
     else:
         print("Error! Choose 1, 2, 3, 4, 5, 6 or 7")
