@@ -55,12 +55,12 @@ if config.MULTIpr:  # in multi-processing mode ...
     # ! DO NOT PLACE imports IN CONDITIONAL 'if'-STATEMENTS WHEN MULTI-PROCESSING !
     import multiprocessing as mp
     from functools import partial
-    # ... still required for single-processing (in multi-processing mode):
+    # ... following is still required for SINGLE-PROCESSING (in multi-processing mode):
     from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, moonage, moonphase, equation_of_time, getParams, find_new_moon
-    # ... required for multi-processing:
+    # ... following is required for MULTI-PROCESSING:
     from sfalmanac.lib.mp_nautical import mp_twilight, mp_moonrise_set, mp_planetstransit, hor_parallax, mp_planetGHA, mp_sunmoon
 else:
-    # ... required for single-processing:
+    # ... following is required for SINGLE-PROCESSING:
     from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, twilight, moonrise_set, moonage, moonphase, equation_of_time, getParams, find_new_moon
 
 
@@ -232,7 +232,6 @@ def lunatikz(phase, dfcm):
 
     if config.dockerized:   # DOCKER ONLY
         dfcm = "../croppedmoon.png"
-    dfcm = dfcm.replace("\\","\\\\")
 
     tikz = r'''\multicolumn{{1}}{{|c|}}{{\multirow{{3}}{{*}}
 {{\begin{{tikzpicture}}
@@ -1349,8 +1348,6 @@ def almanac(first_day, pagenum, ts, spad, df180, df360, dfcm):
     if config.dockerized:   # DOCKER ONLY
         df180 = "../A4chart0-180_P.pdf"
         df360 = "../A4chart180-360_P.pdf"
-    df180 = df180.replace("\\","\\\\")
-    df360 = df360.replace("\\","\\\\")
 
     alm = alm + r'''
     \begin{{titlepage}}
