@@ -24,13 +24,10 @@
 
 # Standard library imports
 import datetime		# required for .timedelta()
-#import math
 from math import copysign as copysign
 
 # Local application imports
-#import config
 from sfalmanac.lib import config as config
-#from alma_skyfield import *
 from sfalmanac.lib import alma_skyfield as alma_skyfield
 
 #----------------------
@@ -391,7 +388,6 @@ def sunalmanac(first_day, pagenum, dfra):
 
     if config.dockerized:   # DOCKER ONLY
         dfra = "../Ra"
-    dfra = dfra.replace("\\","\\\\")
 
     alm = alm + r'''
     \begin{{titlepage}}\vspace*{{1.5cm}}
